==> isCOBOL_2025_R1_1145_9_20250707_40290_Linux.32.i586.tar.gz: sample/eis/others/angularjs/build.sh <==
getIscobol()
{
if [ -z "${ISCOBOL}" ]
then
    cd ../../..
    D=`dirname $0`
    B=`basename $0`
    abspath="`cd \"${D}\" 2>/dev/null && pwd || echo \"${D}\"`/${B}"
    _BIN_DIR=`dirname ${abspath}`
    ISCOBOL=`dirname ${_BIN_DIR}`
fi

if [ -z "${ISCOBOL}" ]
then
   echo "ERROR: The $ISCOBOL variable is not found"
   exit 1
fi

if [ -f "$ISCOBOL/bin/default_java.conf" ]
then
. $ISCOBOL/bin/default_java.conf
fi
}

getJavac()
{
if [ -z "${ISCOBOL_JDK_ROOT}" ]
then

    _JAVAC_LOCATION=`type javac | cut -f3 -d' '` 

    while [ -h "$_JAVAC_LOCATION" ]; do
       ls=`ls -ld "$_JAVAC_LOCATION"`
       link=`expr "$ls" : '.*-> \(.*\)$'`
       if expr "$link" : '/.*' > /dev/null; then
         _JAVAC_LOCATION="$link"
       else
         _JAVAC_LOCATION=`dirname "$_JAVAC_LOCATION"`/"$link"
       fi
    done  

    if [ -z "$_JAVAC_LOCATION" ]
    then
        echo "ERROR: Could not locate JDK. Please ensure that 'javac' is"
        echo "on your PATH or set ISCOBOL_JDK_ROOT"
        exit 1
    fi
    _JDK_BINDIR=`dirname $_JAVAC_LOCATION`
    ISCOBOL_JDK_ROOT=`dirname $_JDK_BINDIR`
fi
}


getIscobol
getJavac

cd $ISCOBOL/sample/eis/others/angularjs

mkdir ./angularjs
cd ./angularjs
mkdir ./css
mkdir ./fonts
mkdir ./js
mkdir ./WEB-INF
cd ./WEB-INF
mkdir ./classes
mkdir ./lib

cd $ISCOBOL/sample/eis/others/angularjs

cp *.html $ISCOBOL/sample/eis/others/angularjs/angularjs
cp veryant.png $ISCOBOL/sample/eis/others/angularjs/angularjs
cp $ISCOBOL/sample/eis/others/angularjs/css/*.css $ISCOBOL/sample/eis/others/angularjs/angularjs/css
cp $ISCOBOL/sample/eis/others/angularjs/fonts/*.* $ISCOBOL/sample/eis/others/angularjs/angularjs/fonts
cp $ISCOBOL/sample/eis/others/angularjs/js/*.js $ISCOBOL/sample/eis/others/angularjs/angularjs/js
cp $ISCOBOL/sample/eis/files/web.xml $ISCOBOL/sample/eis/others/angularjs/angularjs/WEB-INF
cp $ISCOBOL/lib/iscobol.jar $ISCOBOL/sample/eis/others/angularjs/angularjs/WEB-INF/lib
cp $ISCOBOL/lib/itext-2.1.7v?.jar $ISCOBOL/sample/eis/others/angularjs/angularjs/WEB-INF/lib
cp ./*.class $ISCOBOL/sample/eis/others/angularjs/angularjs/WEB-INF/classes
cp iscobol.properties $ISCOBOL/sample/eis/others/angularjs/angularjs/WEB-INF/classes

cd $ISCOBOL/sample/eis/others/angularjs/angularjs

$ISCOBOL_JDK_ROOT/bin/jar -cvf angularjs.war *

==> isCOBOL_2025_R2_1158_10_20251128_41083_Linux.32.i586.tar.gz: sample/eis/others/angularjs/build.sh <==
getIscobol()
{
if [ -z "${ISCOBOL}" ]
then
    cd ../../..
    D=`dirname $0`
    B=`basename $0`
    abspath="`cd \"${D}\" 2>/dev/null && pwd || echo \"${D}\"`/${B}"
    _BIN_DIR=`dirname ${abspath}`
    ISCOBOL=`dirname ${_BIN_DIR}`
fi

if [ -z "${ISCOBOL}" ]
then
   echo "ERROR: The $ISCOBOL variable is not found"
   exit 1
fi

if [ -f "$ISCOBOL/bin/default_java.conf" ]
then
. $ISCOBOL/bin/default_java.conf
fi
}

getJavac()
{
if [ -z "${ISCOBOL_JDK_ROOT}" ]
then

    _JAVAC_LOCATION=`type javac | cut -f3 -d' '` 

    while [ -h "$_JAVAC_LOCATION" ]; do
       ls=`ls -ld "$_JAVAC_LOCATION"`
       link=`expr "$ls" : '.*-> \(.*\)$'`
       if expr "$link" : '/.*' > /dev/null; then
         _JAVAC_LOCATION="$link"
       else
         _JAVAC_LOCATION=`dirname "$_JAVAC_LOCATION"`/"$link"
       fi
    done  

    if [ -z "$_JAVAC_LOCATION" ]
    then
        echo "ERROR: Could not locate JDK. Please ensure that 'javac' is"
        echo "on your PATH or set ISCOBOL_JDK_ROOT"
        exit 1
    fi
    _JDK_BINDIR=`dirname $_JAVAC_LOCATION`
    ISCOBOL_JDK_ROOT=`dirname $_JDK_BINDIR`
fi
}


getIscobol
getJavac

cd $ISCOBOL/sample/eis/others/angularjs

mkdir ./angularjs
cd ./angularjs
mkdir ./css
mkdir ./fonts
mkdir ./js
mkdir ./WEB-INF
cd ./WEB-INF
mkdir ./classes
mkdir ./lib

cd $ISCOBOL/sample/eis/others/angularjs

cp *.html $ISCOBOL/sample/eis/others/angularjs/angularjs
cp veryant.png $ISCOBOL/sample/eis/others/angularjs/angularjs
cp $ISCOBOL/sample/eis/others/angularjs/css/*.css $ISCOBOL/sample/eis/others/angularjs/angularjs/css
cp $ISCOBOL/sample/eis/others/angularjs/fonts/*.* $ISCOBOL/sample/eis/others/angularjs/angularjs/fonts
cp $ISCOBOL/sample/eis/others/angularjs/js/*.js $ISCOBOL/sample/eis/others/angularjs/angularjs/js
cp $ISCOBOL/sample/eis/files/web.xml $ISCOBOL/sample/eis/others/angularjs/angularjs/WEB-INF
cp $ISCOBOL/lib/iscobol.jar $ISCOBOL/sample/eis/others/angularjs/angularjs/WEB-INF/lib
cp $ISCOBOL/lib/openpdf-2.0.3v?.jar $ISCOBOL/sample/eis/others/angularjs/angularjs/WEB-INF/lib
cp ./*.class $ISCOBOL/sample/eis/others/angularjs/angularjs/WEB-INF/classes
cp iscobol.properties $ISCOBOL/sample/eis/others/angularjs/angularjs/WEB-INF/classes

cd $ISCOBOL/sample/eis/others/angularjs/angularjs

$ISCOBOL_JDK_ROOT/bin/jar -cvf angularjs.war *
